@@ -115,6 +115,12 @@
 #else
 #  define KCOLORSCHEME_DEPRECATED_VERSION_6_6(text)
 #endif
+
+#if KCOLORSCHEME_DEPRECATED_WARNINGS_SINCE >= 0x61300
+#  define KCOLORSCHEME_DEPRECATED_VERSION_6_19(text) KCOLORSCHEME_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOLORSCHEME_DEPRECATED_VERSION_6_19(text)
+#endif
 #define KCOLORSCHEME_DEPRECATED_VERSION_6(minor, text)      KCOLORSCHEME_DEPRECATED_VERSION_6_##minor(text)
 #define KCOLORSCHEME_DEPRECATED_VERSION(major, minor, text) KCOLORSCHEME_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCOLORSCHEME_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOLORSCHEME_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
